@@ -26,7 +26,7 @@ use strict;
 use warnings;
 
 package YASF;
-$YASF::VERSION = '0.003';
+$YASF::VERSION = '0.004';
 use 5.008;
 use overload fallback => 0,
     'eq'  => \&_eq,
@@ -36,11 +36,12 @@ use overload fallback => 0,
     'gt'  => \&_gt,
     'ge'  => \&_ge,
     'cmp' => \&_cmp,
+    q{.}  => \&_dot,
+    q{.=} => \&_dotequal,
     q{""} => \&_stringify,
     q{%}  => \&_interpolate;
 
 use Carp qw(carp croak);
-use English qw(-no_match_vars);
 use Exporter qw(import);
 
 BEGIN {
@@ -206,7 +207,7 @@ sub _compile {
             push @stack, [];
             $level++;
             push @opens, $value;
-        } elsif ($type eq 'CLOSE') {
+        } else {
             if ($level) {
                 my $subtree = pop @stack;
                 $level--;
@@ -215,8 +216,6 @@ sub _compile {
             } else {
                 croak "Unmatched closing brace at position $value";
             }
-        } else {
-            croak "Unknown token type: $type\n";
         }
     }
 
@@ -388,6 +387,26 @@ sub _ge {
         ($other ge $self->_stringify) : ($self->_stringify ge $other);
 }
 
+# Handle the '.' operator
+sub _dot {
+    my ($self, $other, $swap) = @_;
+
+    return $swap ?
+        $other . $self->_stringify : $self->_stringify . $other;
+}
+
+# Handle the '.=' operator
+sub _dotequal {
+    my ($self, $other, $swap) = @_;
+
+    if (! $swap) {
+        my $class = ref $self;
+        croak "$class object cannot be on the left of .=";
+    }
+
+    return $other . $self->_stringify;
+}
+
 1;
 
 __END__
@@ -402,7 +421,7 @@ YASF - Yet Another String Formatter
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
 =head1 SYNOPSIS
 
@@ -578,6 +597,18 @@ C<ge>) are all overloaded to stringify the B<YASF> object before doing the
 actual comparison. As with C<"">, if no object-level bindings exist then the
 stringification is just the template string itself.
 
+=item String Concatenation (C<.> and C<.=>)
+
+The string concatenation operators, C<.> and C<.=>, are also overloaded. The
+C<.> operator always stringifies the object involved in the operation (with
+the same effect as the comparison operators when no bindings exist), regardless
+of which side of the operator it appears on.
+
+The C<.=> operator, however, can only accept a B<YASF> object on the right-hand
+side. This is because B<YASF> template strings are (currently) read-only. If
+you try to use an object on the left-hand side of C<.=>, an exception is
+thrown.
+
 =back
 
 Other operators may be overloaded in the future, as deemed useful or
